docs.rs failed to build hardened-malloc-sys-16.0.2026060600
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
hardened-malloc-sys-16.0.2026050400
Rust bindings for GrapheneOS allocator
- Released under the same license as the GrapheneOS allocator.
- The major version follows the GrapheneOS allocator version.
- Use it, harden your memories, spread the love!
Configuration
- Build requires a C23 supporting compiler!
- We follow upstream configuration closely (except
CONFIG_WERROR). - Feature
lightenables light mode, otherwise you're indefaultmode. - Feature
sealenablesCONFIG_SEAL_METADATA, noop if target env isn't GNU. - Use the files
config-{default,light,tiny}.confto fine tune build as needed.
Maintained by Ali Polatel. Up-to-date sources can be found at https://git.sr.ht/~alip/syd and bugs/patches can be submitted by email to ~alip/sydbox-devel@lists.sr.ht. Exherbo related bugs/issues can be submitted to https://gitlab.exherbo.org/groups/sydbox/-/issues. Discuss in #sydbox on Libera Chat.